package vulnerability

import (
	"io"

	grypePkg "github.com/anchore/grype/grype/pkg"
)

// Criteria interfaces are used for FindVulnerabilities calls
type Criteria interface {
	// MatchesVulnerability returns true if the provided value meets the criteria
	MatchesVulnerability(value Vulnerability) (bool, string, error)
}

// MetadataProvider implementations provide ways to look up vulnerability metadata
// Deprecated: vulnerability.Vulnerability objects now have metadata included
type MetadataProvider interface {
	// VulnerabilityMetadata returns the metadata associated with a vulnerability
	// Deprecated: vulnerability.Vulnerability objects now have metadata included
	VulnerabilityMetadata(ref Reference) (*Metadata, error)
}

// Provider is the common interface for vulnerability sources to provide searching and metadata, such as a database
type Provider interface {
	PackageSearchNames(grypePkg.Package) []string
	// FindVulnerabilities returns vulnerabilities matching all the provided criteria
	FindVulnerabilities(criteria ...Criteria) ([]Vulnerability, error)

	MetadataProvider

	io.Closer
}
